var app = require('express')();
var http = require('http').Server(app);
var io = require('socket.io')(http);

var Cylon = require('cylon');

var rbt=Cylon.robot({
  connections: {
    edison:{adaptor: 'intel-iot'}
  },

  devices: {
    servoL: { driver: 'servo', pin: 20 },
    servoR: { driver: 'servo', pin: 14 },
    button: { driver: 'button', pin: 15 },
  },
});
var bot=new EdisonRobot(rbt);
var basketball=new Basketball(bot,rbt);
var mode="remote";
rbt.work=function(my) {
  app.get('/', function(req, res){
    res.sendFile(__dirname+'/index.html');
  });
  io.on('connection', function(socket){
    console.log('a user connected');
    socket.on('keyDown',remoteKeyDown);
    socket.on('keyUp',remoteKeyUp);
    socket.on('basketball',remoteBasketBall);

  });
  http.listen(3000, function(){
    console.log('listening on *:3000');
  });
  
};
function remoteKeyDown(val){
  if(mode!="remote")return;
  switch(val){
    case 37:	//left
      bot.moveMotors(-100,100);
      break;
    case 38:	//up
      bot.moveMotors(100,100);
      break;
    case 39:	//right
      bot.moveMotors(100,-100);
      break;
    case 40:	//down
      bot.moveMotors(-100,-100);
      break;
  }
}
function remoteKeyUp(val){
  if(mode!="remote")return;
  bot.moveMotors(0,0);
}
function remoteBasketBall(val){
  if(val){
    mode="basketball";
    basketball.start();
  }else{
    mode="remote";
    basketball.stop();
  }
}
function EdisonRobot(cBot){
  var self=this;
  var me=cBot;

  this.moveMotorsByAng=function(angL,angR){
    if(self.angL==angL && self.angR==angR)
      return;
    self.angL=angL;
    self.angR=angR;
    me.servoL.angle(angL);
    me.servoR.angle(angR);
  }
  this.moveMotors=function(speedL,speedR){
    var angL=self.speedToAngle(speedL);
    var angR=self.speedToAngle(-speedR);
    console.log(speedL,speedR,angL,angR);
    self.moveMotorsByAng(angL,angR);
  }
  this.speedToAngle=function(speed){
    if(speed>100)speed=100;
    else if(speed<-100)speed=-100;
    var result=speed/100.0*90+90;
    return result;
  }
}

function Basketball(eBot,cBot){
  var self=this;
  var speedMax=10;
  self.move=function(){
    var rndSpeedL=Math.round((2*Math.random()-1)*speedMax);
    var rndSpeedR=Math.round((2*Math.random()-1)*speedMax);
    var rndTime=Math.random()*2000+500;
    eBot.moveMotors(rndSpeedL,rndSpeedR);
    self.moveTimer=setTimeout(self.move,rndTime);
  }

  self.start=function(){
    self.move();
    cBot.button.once('push',self.goal);
  }
  self.stop=function(){
    clearTimeout(self.moveTimer);
    cBot.button.removeListener('push',self.goal);
    eBot.moveMotors(0,0);
  }
  self.goal=function(){
    console.log("goal!");
    self.stop();
    eBot.moveMotors(-50,50);
    setTimeout(function(){console.log("start again");self.start();},3000);
  }
}


rbt.start();
